@@ -1,8 +1,8 @@
 #!/bin/sh
 
-ltlfilt=../../src/bin/ltlfilt
-ltl2tgba=../../src/bin/ltl2tgba
-dstar2tgba=../../src/bin/dstar2tgba
+ltlfilt=../../bin/ltlfilt
+ltl2tgba=../../bin/ltl2tgba
+dstar2tgba=../../bin/dstar2tgba
 timeout='timeout -sKILL 1h'
 stats=--stats="%s, %e, %t, %a, %c, %d, %p, %r"
 empty='-, -, -, -, -, -, -, -'
@@ -17,15 +17,15 @@ while IFS=, read f type accmax accmin; do
 
   case $type in
   *TCONG*)
-    echo "$n.log:; ./stat.sh $n '$f' $type $accmax >\$@" >> stats.tmp
+    echo "$n.log:; ./stat-gen.sh $n '$f' $type $accmax >\$@" >> stats.tmp
     all="$all $n.log"
     n=`expr $n + 1`
-    echo "$n.log:; ./stat.sh $n '$f' DRA-CONG $accmax >\$@" >> stats.tmp
+    echo "$n.log:; ./stat-gen.sh $n '$f' DRA-CONG $accmax >\$@" >> stats.tmp
     all="$all $n.log"
     n=`expr $n + 1`
     ;;
   *)
-    echo "$n.log:; ./stat.sh $n '$f' $type $accmax >\$@" >> stats.tmp
+    echo "$n.log:; ./stat-gen.sh $n '$f' $type $accmax >\$@" >> stats.tmp
     all="$all $n.log"
     n=`expr $n + 1`
     ;;
@@ -34,7 +34,7 @@ done < info.ltl
 
 cat > stats.mk <<EOF
 ALL = $all
-all.log: \$(ALL)
+all.csv: \$(ALL)
 	cat \$(ALL) >\$@
 EOF
 cat stats.tmp >> stats.mk
