@@ -1,5 +1,5 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2010-2017 Laboratoire de Recherche et Développement de
+// Copyright (C) 2010-2018 Laboratoire de Recherche et Développement de
 // l'Epita (LRDE).
 //
 // This file is part of Spot, a model checking library.
@@ -19,6 +19,7 @@
 
 //#define TRACE
 
+#include "config.h"
 #include <iostream>
 #ifdef TRACE
 #define trace std::clog
@@ -259,7 +260,10 @@ namespace spot
   state_ta_explicit*
   state_ta_explicit::clone() const
   {
-    return new state_ta_explicit(*this);
+    return new state_ta_explicit(tgba_state_, tgba_condition_,
+                                 is_initial_state_,
+                                 is_accepting_state_,
+                                 is_livelock_accepting_state_, transitions_);
   }
 
   void
@@ -390,7 +394,7 @@ namespace spot
         {
           auto i =
             down_cast<state_ta_explicit*>(get_artificial_initial_state());
-          create_transition(i, condition, 0U, s);
+          create_transition(i, condition, {}, s);
         }
   }
 
