@@ -32,6 +32,7 @@
 #include <spot/twaalgos/totgba.hh>
 #include <spot/twaalgos/cobuchi.hh>
 
+using namespace std::string_literals;
 
 namespace spot
 {
@@ -460,7 +461,7 @@ namespace spot
           goto break2;
         default:
           throw std::runtime_error
-            (std::string("nesting_depth(): unknown operator '") + c + '\'');
+            ("nesting_depth(): unknown operator '"s + c + '\'');
         }
   break2:
     if (want_nnf)
@@ -468,4 +469,9 @@ namespace spot
     const op* vd = v.data();
     return nesting_depth(f, vd, vd + v.size());
   }
+
+  bool is_liveness(formula f)
+  {
+    return is_liveness_automaton(ltl_to_tgba_fm(f, spot::make_bdd_dict()));
+  }
 }
