@@ -1,5 +1,5 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2015, 2016, 2017 Laboratoire de Recherche et
+// Copyright (C) 2015-2018 Laboratoire de Recherche et
 // Développement de l'Epita.
 //
 // This file is part of Spot, a model checking library.
@@ -17,6 +17,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "config.h"
 #include <spot/twaalgos/sepsets.hh>
 #include <spot/twaalgos/sccinfo.hh>
 
@@ -34,14 +35,14 @@ namespace spot
 
   bool has_separate_sets(const const_twa_graph_ptr& aut)
   {
-    return common_sets(aut) == 0U;
+    return !common_sets(aut);
   }
 
   twa_graph_ptr
   separate_sets_here(const twa_graph_ptr& aut)
   {
     auto common = common_sets(aut);
-    if (common == 0U)
+    if (!common)
       return aut;
     // Each Fin(first) should be replaced by Fin(second).
     std::vector<std::pair<acc_cond::mark_t, acc_cond::mark_t>> map;
@@ -68,7 +69,7 @@ namespace spot
             break;
           case acc_cond::acc_op::Fin:
           case acc_cond::acc_op::FinNeg:
-            if ((pos[-1].mark & common) == 0U)
+            if (!(pos[-1].mark & common))
               break;
             for (auto p: map)
               if (pos[-1].mark & p.first)
@@ -87,7 +88,7 @@ namespace spot
     // Fix the edges
     for (auto& t: aut->edges())
       {
-        if ((t.acc & common) == 0U)
+        if (!(t.acc & common))
           continue;
         for (auto p: map)
           if (t.acc & p.first)
