@@ -22,6 +22,11 @@
 #include <spot/misc/hash.hh>
 #include <spot/twaalgos/isweakscc.hh>
 #include <spot/twaalgos/mask.hh>
+#include <spot/twaalgos/minimize.hh>
+#include <spot/twaalgos/isdet.hh>
+#include <spot/twaalgos/sccfilter.hh>
+
+using namespace std::string_literals;
 
 namespace spot
 {
@@ -206,7 +211,7 @@ namespace spot
   {
     if (keep_opt == nullptr || *keep_opt == 0)
       throw std::runtime_error
-        (std::string("option for decompose_scc() should not be empty"));
+        ("option for decompose_scc() should not be empty");
 
     enum strength {
       Ignore = 0,
@@ -247,7 +252,7 @@ namespace spot
             if ((long unsigned) scc >= n)
               {
                 throw std::runtime_error
-                  (std::string("decompose_scc(): there is no SCC ")
+                  ("decompose_scc(): there is no SCC "s
                    + std::to_string(scc) + " in this automaton");
               }
             keep_opt = endptr;
@@ -272,7 +277,7 @@ namespace spot
             if (j != scc + 1)
               {
                 throw std::runtime_error
-                  (std::string("decompose_scc(): there is no SCC 'a")
+                  ("decompose_scc(): there is no SCC 'a"s
                    + std::to_string(scc) + "' in this automaton");
               }
             keep_opt = endptr;
@@ -289,7 +294,7 @@ namespace spot
           break;
         default:
           throw std::runtime_error
-            (std::string("unknown option for decompose_scc(): ") + c);
+            ("unknown option for decompose_scc(): "s + c);
         }
 
     auto p = aut->acc().unsat_mark();
@@ -399,4 +404,13 @@ namespace spot
     std::string num = std::to_string(scc_num);
     return decompose_scc(sm, (accepting ? ('a' + num) : num).c_str());
   }
+
+  bool
+  is_liveness_automaton(const const_twa_graph_ptr& aut)
+  {
+    auto mon = minimize_monitor(scc_filter_states(aut));
+    return mon->num_states() == 1 && is_complete(mon);
+  }
+
+
 }
